package com.diagbot.web;


import java.util.List;

import javax.validation.Valid;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.diagbot.annotation.SysLogger;
import com.diagbot.dto.ItemIndexDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.facade.IndexDataFacade;
import com.diagbot.vo.IndexDataFindVO;
import com.diagbot.vo.IndexDataSaveVO;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * <p>
 * 指标数据表 前端控制器
 * </p>
 *
 * @author wangfeng
 * 
 * @since 2019-03-11
 */

@RestController
@RequestMapping("/indexData")
@Api(value = "指标数据API[by:wangfeng]", tags = { "WF-2期-指标数据API" })
@SuppressWarnings("unchecked")
public class IndexDataController {
	
	@Autowired
	IndexDataFacade indexDataFacade;
	
	@ApiOperation(value = "根据疾病Id获取指标配置[by:wangfeng]", notes = "根据疾病Id获取指标配置")
	@PostMapping("/getIndexDatas")
	@SysLogger("getIndexDatas")
	@Transactional
	public RespDTO<List<ItemIndexDTO>> getIndexDatas(@Valid @RequestBody IndexDataFindVO indexDataFindVO) {

		List<ItemIndexDTO> data = indexDataFacade.getIndexDataAll(indexDataFindVO);

		return RespDTO.onSuc(data);
	}
	
	@ApiOperation(value = "保存指标数据[by:wangfeng]", notes = "根据疾病Id获取指标配置")
	@PostMapping("/saveIndexDatas")
	@SysLogger("saveIndexDatas")
	@Transactional
	public RespDTO<Boolean> saveIndexDatas(@Valid @RequestBody IndexDataSaveVO indexDataSaveVO) {

		boolean res = indexDataFacade.saveIndexDatas(indexDataSaveVO);

		return RespDTO.onSuc(res);
	}
	
}
